==> chromium-browser_25.0.1364.160.orig.tar.xz: chromium-browser-25.0.1364.160/src/chrome/browser/extensions/extension_input_module_constants.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Constants used for the input API and the Windows API.

#ifndef CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_MODULE_CONSTANTS_H_
#define CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_MODULE_CONSTANTS_H_

namespace extension_input_module_constants {

// Keys used in serializing input data & events.
extern const char kAnnotationKey[];
extern const char kAuxiliaryTextKey[];
extern const char kAuxiliaryTextVisibleKey[];
extern const char kCandidateIdKey[];
extern const char kCandidateKey[];
extern const char kCandidatesKey[];
extern const char kCheckedKey[];
extern const char kContextIdKey[];
extern const char kCursorKey[];
extern const char kCursorVisibleKey[];
extern const char kEnabledKey[];
extern const char kEndKey[];
extern const char kEngineIdKey[];
extern const char kIdKey[];
extern const char kItemsKey[];
extern const char kKeyKey[];
extern const char kLabelKey[];
extern const char kPageSizeKey[];
extern const char kParentIdKey[];
extern const char kPropertiesKey[];
extern const char kSegmentsKey[];
extern const char kSelectionEndKey[];
extern const char kSelectionStartKey[];
extern const char kStartKey[];
extern const char kStyleDoubleUnderline[];
extern const char kStyleKey[];
extern const char kStyleUnderline[];
extern const char kTextKey[];
extern const char kUsageBodyKey[];
extern const char kUsageKey[];
extern const char kUsageTitleKey[];
extern const char kVerticalKey[];
extern const char kVisibleKey[];

};  // namespace extension_input_module_constants

#endif  // CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_MODULE_CONSTANTS_H_

==> chromium-browser_28.0.1500.95.orig.tar.xz: chromium-browser-28.0.1500.95/src/chrome/browser/extensions/extension_input_module_constants.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Constants used for the input API and the Windows API.

#ifndef CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_MODULE_CONSTANTS_H_
#define CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_MODULE_CONSTANTS_H_

namespace extension_input_module_constants {

// Keys used in serializing input data & events.
extern const char kAnnotationKey[];
extern const char kAuxiliaryTextKey[];
extern const char kAuxiliaryTextVisibleKey[];
extern const char kCandidateIdKey[];
extern const char kCandidateKey[];
extern const char kCandidatesKey[];
extern const char kCheckedKey[];
extern const char kContextIdKey[];
extern const char kCursorKey[];
extern const char kCursorVisibleKey[];
extern const char kEnabledKey[];
extern const char kEndKey[];
extern const char kEngineIdKey[];
extern const char kIdKey[];
extern const char kItemsKey[];
extern const char kKeyKey[];
extern const char kLabelKey[];
extern const char kLengthKey[];
extern const char kOffsetKey[];
extern const char kPageSizeKey[];
extern const char kParentIdKey[];
extern const char kPropertiesKey[];
extern const char kSegmentsKey[];
extern const char kSelectionEndKey[];
extern const char kSelectionStartKey[];
extern const char kStartKey[];
extern const char kStyleDoubleUnderline[];
extern const char kStyleKey[];
extern const char kStyleUnderline[];
extern const char kTextKey[];
extern const char kUsageBodyKey[];
extern const char kUsageKey[];
extern const char kUsageTitleKey[];
extern const char kVerticalKey[];
extern const char kVisibleKey[];
extern const char kWindowPositionKey[];

};  // namespace extension_input_module_constants

#endif  // CHROME_BROWSER_EXTENSIONS_EXTENSION_INPUT_MODULE_CONSTANTS_H_
